@@ -25,7 +25,7 @@
 #ifndef __NMV_GDBMI_PARSER_H
 #define __NMV_GDBMI_PARSER_H
 #include <boost/variant.hpp>
-#include <iostream>
+#include <iosfwd>
 #include "nmv-i-debugger.h"
 #include "nmv-dbg-common.h"
 
@@ -256,7 +256,8 @@ public:
 
     void get_result_content (list<GDBMIResultSafePtr> &a_list) const
     {
-        THROW_IF_FAIL (!empty () && content_type () == RESULT_TYPE) ;
+        if (empty ()) {return;}
+        THROW_IF_FAIL (content_type () == RESULT_TYPE) ;
         list<boost::variant<GDBMIResultSafePtr,GDBMIValueSafePtr> >::const_iterator it;
         for (it= m_content.begin () ; it!= m_content.end () ; ++it) {
             a_list.push_back (boost::get<GDBMIResultSafePtr> (*it)) ;
@@ -265,7 +266,8 @@ public:
 
     void get_value_content (list<GDBMIValueSafePtr> &a_list) const
     {
-        THROW_IF_FAIL (!empty () && content_type () == VALUE_TYPE) ;
+        if (empty ()) {return;}
+        THROW_IF_FAIL (content_type () == VALUE_TYPE) ;
         list<boost::variant<GDBMIResultSafePtr,GDBMIValueSafePtr> >::const_iterator it;
         for (it= m_content.begin () ; it!= m_content.end () ; ++it) {
             a_list.push_back (boost::get<GDBMIValueSafePtr> (*it)) ;
@@ -560,6 +562,28 @@ bool parse_overloads_choice_prompt
                          UString::size_type a_from,
                          UString::size_type &a_to,
                          vector<IDebugger::OverloadsChoiceEntry> &a_prompts) ;
+
+bool parse_register_names (const UString &a_input,
+                           UString::size_type a_from,
+                           UString::size_type &a_to,
+                           std::map<IDebugger::register_id_t, UString> &a_registers);
+
+bool parse_changed_registers (const UString &a_input,
+                              UString::size_type a_from,
+                              UString::size_type &a_to,
+                              std::list<IDebugger::register_id_t> &a_registers);
+
+bool parse_register_values (const UString &a_input,
+                            UString::size_type a_from,
+                            UString::size_type &a_to,
+                            std::map<IDebugger::register_id_t, UString> &a_values);
+
+bool parse_memory_values (const UString &a_input,
+                          UString::size_type a_from,
+                          UString::size_type &a_to,
+                          size_t& a_start_addr,
+                          std::vector<uint8_t> &a_values);
+
 NEMIVER_END_NAMESPACE (nemiver)
 #endif //__NMV_GDBMI_PARSER_H
 
